@@ -28,9 +28,16 @@ function q = round (q)
     print_usage ();
   endif
   
-  q.w = round (q.w);
-  q.x = round (q.x);
-  q.y = round (q.y);
-  q.z = round (q.z);
+  q.w = builtin ("round", q.w);
+  q.x = builtin ("round", q.x);
+  q.y = builtin ("round", q.y);
+  q.z = builtin ("round", q.z);
 
 endfunction
+
+
+%!test
+%! q = quaternion (1.4, 2.6, 3.5, 4.2);
+%! result = round (q);
+%! expected = quaternion (1, 3, 4, 4);
+%! assert (result == expected);
